@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2014 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -1019,7 +1019,7 @@ namespace gloox
       m_smQueue.insert( std::make_pair( ++m_smSent, tag ) );
       m_queueMutex.unlock();
     }
-    else if( del )
+    else if( del || m_smContext < CtxSMEnabled )
       delete tag;
   }
 
