@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2014 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -909,7 +909,7 @@ namespace gloox
       enum SMContext
       {
         CtxSMInvalid,                    /**< Initial value. */
-        CtxSMFailed,                      /**< Either of the above failed. */
+        CtxSMFailed,                     /**< Either of the below failed. */
         CtxSMEnable,                     /**< 'enable' request sent */
         CtxSMResume,                     /**< 'resume' request sent */
         CtxSMEnabled,                    /**< Stream Management successfully enabled. */
