@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2014 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -99,6 +99,10 @@ namespace gloox
       }
     }
 
+    Session::Reason::~Reason()
+    {
+    }
+
     const std::string& Session::Reason::filterString() const
     {
       static const std::string filter = "jingle/reason";
@@ -318,7 +322,7 @@ namespace gloox
 
     bool Session::sessionAccept( const PluginList& plugins )
     {
-      if( plugins.empty() || m_state >= Pending )
+      if( plugins.empty() || m_state != Pending )
         return false;
 
       m_state = Active;
