@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2014 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -147,7 +147,7 @@ namespace gloox
             /**
              * Virtual destructor.
              */
-            virtual ~Reason() {}
+            virtual ~Reason();
 
             /**
              * Returns the reason for the session termination.
